testutil

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 14, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Overview

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Package testutil is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockAuthenticator

type MockAuthenticator struct {
	// contains filtered or unexported fields
}

MockAuthenticator is a mock of Authenticator interface.

func NewMockAuthenticator

func NewMockAuthenticator(ctrl *gomock.Controller) *MockAuthenticator

NewMockAuthenticator creates a new mock instance.

func (*MockAuthenticator) Authenticate

func (m *MockAuthenticator) Authenticate(ctx context.Context) (string, error)

Authenticate mocks base method.

func (*MockAuthenticator) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

type MockAuthenticatorMockRecorder

type MockAuthenticatorMockRecorder struct {
	// contains filtered or unexported fields
}

MockAuthenticatorMockRecorder is the mock recorder for MockAuthenticator.

func (*MockAuthenticatorMockRecorder) Authenticate

func (mr *MockAuthenticatorMockRecorder) Authenticate(ctx any) *gomock.Call

Authenticate indicates an expected call of Authenticate.

type MockCallerRegistry

type MockCallerRegistry struct {
	// contains filtered or unexported fields
}

MockCallerRegistry is a mock of CallerRegistry interface.

func NewMockCallerRegistry

func NewMockCallerRegistry(ctrl *gomock.Controller) *MockCallerRegistry

NewMockCallerRegistry creates a new mock instance.

func (*MockCallerRegistry) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockCallerRegistry) IsPermitted

func (m *MockCallerRegistry) IsPermitted(ctx context.Context, callerIdentity, tenantID string) (bool, error)

IsPermitted mocks base method.

type MockCallerRegistryMockRecorder

type MockCallerRegistryMockRecorder struct {
	// contains filtered or unexported fields
}

MockCallerRegistryMockRecorder is the mock recorder for MockCallerRegistry.

func (*MockCallerRegistryMockRecorder) IsPermitted

func (mr *MockCallerRegistryMockRecorder) IsPermitted(ctx, callerIdentity, tenantID any) *gomock.Call

IsPermitted indicates an expected call of IsPermitted.

type MockChecker

type MockChecker struct {
	// contains filtered or unexported fields
}

MockChecker is a mock of Checker interface.

func NewMockChecker

func NewMockChecker(ctrl *gomock.Controller) *MockChecker

NewMockChecker creates a new mock instance.

func (*MockChecker) Check

func (m *MockChecker) Check(ctx context.Context) error

Check mocks base method.

func (*MockChecker) EXPECT

func (m *MockChecker) EXPECT() *MockCheckerMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockChecker) Name

func (m *MockChecker) Name() string

Name mocks base method.

type MockCheckerMockRecorder

type MockCheckerMockRecorder struct {
	// contains filtered or unexported fields
}

MockCheckerMockRecorder is the mock recorder for MockChecker.

func (*MockCheckerMockRecorder) Check

func (mr *MockCheckerMockRecorder) Check(ctx any) *gomock.Call

Check indicates an expected call of Check.

func (*MockCheckerMockRecorder) Name

func (mr *MockCheckerMockRecorder) Name() *gomock.Call

Name indicates an expected call of Name.

type MockClient added in v0.8.0

type MockClient struct {
	// contains filtered or unexported fields
}

MockClient is a mock of Client interface.

func NewMockClient added in v0.8.0

func NewMockClient(ctrl *gomock.Controller) *MockClient

NewMockClient creates a new mock instance.

func (*MockClient) Close added in v0.8.0

func (m *MockClient) Close() error

Close mocks base method.

func (*MockClient) EXPECT added in v0.8.0

func (m *MockClient) EXPECT() *MockClientMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockClient) IssueToken added in v0.8.0

IssueToken mocks base method.

func (*MockClient) RefreshToken added in v0.8.0

RefreshToken mocks base method.

func (*MockClient) RevokeAllForAudience added in v0.8.0

RevokeAllForAudience mocks base method.

func (*MockClient) RevokeAllForUserAndAudience added in v0.8.0

func (m *MockClient) RevokeAllForUserAndAudience(ctx context.Context, req *tokenv1.RevokeUserAndAudienceRequest) (*tokenv1.RevokeTokenResponse, error)

RevokeAllForUserAndAudience mocks base method.

func (*MockClient) RevokeAllUserTokens added in v0.8.0

func (m *MockClient) RevokeAllUserTokens(ctx context.Context, req *tokenv1.RevokeUserRequest) (*tokenv1.RevokeTokenResponse, error)

RevokeAllUserTokens mocks base method.

func (*MockClient) RevokeToken added in v0.8.0

RevokeToken mocks base method.

type MockClientMockRecorder added in v0.8.0

type MockClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockClientMockRecorder is the mock recorder for MockClient.

func (*MockClientMockRecorder) Close added in v0.8.0

func (mr *MockClientMockRecorder) Close() *gomock.Call

Close indicates an expected call of Close.

func (*MockClientMockRecorder) IssueToken added in v0.8.0

func (mr *MockClientMockRecorder) IssueToken(ctx, req any) *gomock.Call

IssueToken indicates an expected call of IssueToken.

func (*MockClientMockRecorder) RefreshToken added in v0.8.0

func (mr *MockClientMockRecorder) RefreshToken(ctx, req any) *gomock.Call

RefreshToken indicates an expected call of RefreshToken.

func (*MockClientMockRecorder) RevokeAllForAudience added in v0.8.0

func (mr *MockClientMockRecorder) RevokeAllForAudience(ctx, req any) *gomock.Call

RevokeAllForAudience indicates an expected call of RevokeAllForAudience.

func (*MockClientMockRecorder) RevokeAllForUserAndAudience added in v0.8.0

func (mr *MockClientMockRecorder) RevokeAllForUserAndAudience(ctx, req any) *gomock.Call

RevokeAllForUserAndAudience indicates an expected call of RevokeAllForUserAndAudience.

func (*MockClientMockRecorder) RevokeAllUserTokens added in v0.8.0

func (mr *MockClientMockRecorder) RevokeAllUserTokens(ctx, req any) *gomock.Call

RevokeAllUserTokens indicates an expected call of RevokeAllUserTokens.

func (*MockClientMockRecorder) RevokeToken added in v0.8.0

func (mr *MockClientMockRecorder) RevokeToken(ctx, req any) *gomock.Call

RevokeToken indicates an expected call of RevokeToken.

type MockIdempotencyStore added in v0.4.0

type MockIdempotencyStore struct {
	// contains filtered or unexported fields
}

MockIdempotencyStore is a mock of IdempotencyStore interface.

func NewMockIdempotencyStore added in v0.4.0

func NewMockIdempotencyStore(ctrl *gomock.Controller) *MockIdempotencyStore

NewMockIdempotencyStore creates a new mock instance.

func (*MockIdempotencyStore) EXPECT added in v0.4.0

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockIdempotencyStore) Get added in v0.4.0

func (m *MockIdempotencyStore) Get(ctx context.Context, key string) ([]byte, bool, error)

Get mocks base method.

func (*MockIdempotencyStore) SetNX added in v0.4.0

func (m *MockIdempotencyStore) SetNX(ctx context.Context, key string, value []byte) (bool, error)

SetNX mocks base method.

type MockIdempotencyStoreMockRecorder added in v0.4.0

type MockIdempotencyStoreMockRecorder struct {
	// contains filtered or unexported fields
}

MockIdempotencyStoreMockRecorder is the mock recorder for MockIdempotencyStore.

func (*MockIdempotencyStoreMockRecorder) Get added in v0.4.0

func (mr *MockIdempotencyStoreMockRecorder) Get(ctx, key any) *gomock.Call

Get indicates an expected call of Get.

func (*MockIdempotencyStoreMockRecorder) SetNX added in v0.4.0

func (mr *MockIdempotencyStoreMockRecorder) SetNX(ctx, key, value any) *gomock.Call

SetNX indicates an expected call of SetNX.

type MockKeyManager added in v0.2.0

type MockKeyManager struct {
	// contains filtered or unexported fields
}

MockKeyManager is a mock of KeyManager interface.

func NewMockKeyManager added in v0.2.0

func NewMockKeyManager(ctrl *gomock.Controller) *MockKeyManager

NewMockKeyManager creates a new mock instance.

func (*MockKeyManager) EXPECT added in v0.2.0

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockKeyManager) GetAllKeyInfo added in v0.2.0

func (m *MockKeyManager) GetAllKeyInfo(ctx context.Context) ([]keys.KeyInfo, error)

GetAllKeyInfo mocks base method.

func (*MockKeyManager) GetCurrentKeyInfo added in v0.2.0

func (m *MockKeyManager) GetCurrentKeyInfo(ctx context.Context) (*keys.KeyInfo, error)

GetCurrentKeyInfo mocks base method.

func (*MockKeyManager) GetCurrentSigningKey added in v0.2.0

func (m *MockKeyManager) GetCurrentSigningKey(ctx context.Context) (*rsa.PrivateKey, string, error)

GetCurrentSigningKey mocks base method.

func (*MockKeyManager) GetJWKS added in v0.2.0

func (m *MockKeyManager) GetJWKS(ctx context.Context) (*keys.JWKS, error)

GetJWKS mocks base method.

func (*MockKeyManager) GetKeyInfo added in v0.2.0

func (m *MockKeyManager) GetKeyInfo(ctx context.Context, keyID string) (*keys.KeyInfo, error)

GetKeyInfo mocks base method.

func (*MockKeyManager) GetPublicKey added in v0.2.0

func (m *MockKeyManager) GetPublicKey(ctx context.Context, keyID string) (*rsa.PublicKey, error)

GetPublicKey mocks base method.

func (*MockKeyManager) IsRunning added in v0.2.0

func (m *MockKeyManager) IsRunning() bool

IsRunning mocks base method.

func (*MockKeyManager) RotateKeys added in v0.2.0

func (m *MockKeyManager) RotateKeys(ctx context.Context) error

RotateKeys mocks base method.

func (*MockKeyManager) Shutdown added in v0.2.0

func (m *MockKeyManager) Shutdown(ctx context.Context) error

Shutdown mocks base method.

func (*MockKeyManager) Start added in v0.2.0

func (m *MockKeyManager) Start(ctx context.Context) error

Start mocks base method.

type MockKeyManagerMockRecorder added in v0.2.0

type MockKeyManagerMockRecorder struct {
	// contains filtered or unexported fields
}

MockKeyManagerMockRecorder is the mock recorder for MockKeyManager.

func (*MockKeyManagerMockRecorder) GetAllKeyInfo added in v0.2.0

func (mr *MockKeyManagerMockRecorder) GetAllKeyInfo(ctx any) *gomock.Call

GetAllKeyInfo indicates an expected call of GetAllKeyInfo.

func (*MockKeyManagerMockRecorder) GetCurrentKeyInfo added in v0.2.0

func (mr *MockKeyManagerMockRecorder) GetCurrentKeyInfo(ctx any) *gomock.Call

GetCurrentKeyInfo indicates an expected call of GetCurrentKeyInfo.

func (*MockKeyManagerMockRecorder) GetCurrentSigningKey added in v0.2.0

func (mr *MockKeyManagerMockRecorder) GetCurrentSigningKey(ctx any) *gomock.Call

GetCurrentSigningKey indicates an expected call of GetCurrentSigningKey.

func (*MockKeyManagerMockRecorder) GetJWKS added in v0.2.0

func (mr *MockKeyManagerMockRecorder) GetJWKS(ctx any) *gomock.Call

GetJWKS indicates an expected call of GetJWKS.

func (*MockKeyManagerMockRecorder) GetKeyInfo added in v0.2.0

func (mr *MockKeyManagerMockRecorder) GetKeyInfo(ctx, keyID any) *gomock.Call

GetKeyInfo indicates an expected call of GetKeyInfo.

func (*MockKeyManagerMockRecorder) GetPublicKey added in v0.2.0

func (mr *MockKeyManagerMockRecorder) GetPublicKey(ctx, keyID any) *gomock.Call

GetPublicKey indicates an expected call of GetPublicKey.

func (*MockKeyManagerMockRecorder) IsRunning added in v0.2.0

func (mr *MockKeyManagerMockRecorder) IsRunning() *gomock.Call

IsRunning indicates an expected call of IsRunning.

func (*MockKeyManagerMockRecorder) RotateKeys added in v0.2.0

func (mr *MockKeyManagerMockRecorder) RotateKeys(ctx any) *gomock.Call

RotateKeys indicates an expected call of RotateKeys.

func (*MockKeyManagerMockRecorder) Shutdown added in v0.2.0

func (mr *MockKeyManagerMockRecorder) Shutdown(ctx any) *gomock.Call

Shutdown indicates an expected call of Shutdown.

func (*MockKeyManagerMockRecorder) Start added in v0.2.0

func (mr *MockKeyManagerMockRecorder) Start(ctx any) *gomock.Call

Start indicates an expected call of Start.

type MockLock added in v0.6.0

type MockLock struct {
	// contains filtered or unexported fields
}

MockLock is a mock of Lock interface.

func NewMockLock added in v0.6.0

func NewMockLock(ctrl *gomock.Controller) *MockLock

NewMockLock creates a new mock instance.

func (*MockLock) EXPECT added in v0.6.0

func (m *MockLock) EXPECT() *MockLockMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockLock) Release added in v0.6.0

func (m *MockLock) Release(ctx context.Context) error

Release mocks base method.

type MockLockMockRecorder added in v0.6.0

type MockLockMockRecorder struct {
	// contains filtered or unexported fields
}

MockLockMockRecorder is the mock recorder for MockLock.

func (*MockLockMockRecorder) Release added in v0.6.0

func (mr *MockLockMockRecorder) Release(ctx any) *gomock.Call

Release indicates an expected call of Release.

type MockLocker added in v0.6.0

type MockLocker struct {
	// contains filtered or unexported fields
}

MockLocker is a mock of Locker interface.

func NewMockLocker added in v0.6.0

func NewMockLocker(ctrl *gomock.Controller) *MockLocker

NewMockLocker creates a new mock instance.

func (*MockLocker) Acquire added in v0.6.0

func (m *MockLocker) Acquire(ctx context.Context, key string, ttl time.Duration) (lock.Lock, error)

Acquire mocks base method.

func (*MockLocker) EXPECT added in v0.6.0

func (m *MockLocker) EXPECT() *MockLockerMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

type MockLockerMockRecorder added in v0.6.0

type MockLockerMockRecorder struct {
	// contains filtered or unexported fields
}

MockLockerMockRecorder is the mock recorder for MockLocker.

func (*MockLockerMockRecorder) Acquire added in v0.6.0

func (mr *MockLockerMockRecorder) Acquire(ctx, key, ttl any) *gomock.Call

Acquire indicates an expected call of Acquire.

type MockLogger

type MockLogger struct {
	// contains filtered or unexported fields
}

MockLogger is a mock of Logger interface.

func NewMockLogger

func NewMockLogger(ctrl *gomock.Controller) *MockLogger

NewMockLogger creates a new mock instance.

func (*MockLogger) Debug

func (m *MockLogger) Debug(ctx context.Context, msg string, keysAndValues ...any)

Debug mocks base method.

func (*MockLogger) EXPECT

func (m *MockLogger) EXPECT() *MockLoggerMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockLogger) Error

func (m *MockLogger) Error(ctx context.Context, msg string, keysAndValues ...any)

Error mocks base method.

func (*MockLogger) Info

func (m *MockLogger) Info(ctx context.Context, msg string, keysAndValues ...any)

Info mocks base method.

func (*MockLogger) Warn

func (m *MockLogger) Warn(ctx context.Context, msg string, keysAndValues ...any)

Warn mocks base method.

func (*MockLogger) With

func (m *MockLogger) With(keysAndValues ...any) observability.Logger

With mocks base method.

type MockLoggerMockRecorder

type MockLoggerMockRecorder struct {
	// contains filtered or unexported fields
}

MockLoggerMockRecorder is the mock recorder for MockLogger.

func (*MockLoggerMockRecorder) Debug

func (mr *MockLoggerMockRecorder) Debug(ctx, msg any, keysAndValues ...any) *gomock.Call

Debug indicates an expected call of Debug.

func (*MockLoggerMockRecorder) Error

func (mr *MockLoggerMockRecorder) Error(ctx, msg any, keysAndValues ...any) *gomock.Call

Error indicates an expected call of Error.

func (*MockLoggerMockRecorder) Info

func (mr *MockLoggerMockRecorder) Info(ctx, msg any, keysAndValues ...any) *gomock.Call

Info indicates an expected call of Info.

func (*MockLoggerMockRecorder) Warn

func (mr *MockLoggerMockRecorder) Warn(ctx, msg any, keysAndValues ...any) *gomock.Call

Warn indicates an expected call of Warn.

func (*MockLoggerMockRecorder) With

func (mr *MockLoggerMockRecorder) With(keysAndValues ...any) *gomock.Call

With indicates an expected call of With.

type MockMetrics

type MockMetrics struct {
	// contains filtered or unexported fields
}

MockMetrics is a mock of Metrics interface.

func NewMockMetrics

func NewMockMetrics(ctrl *gomock.Controller) *MockMetrics

NewMockMetrics creates a new mock instance.

func (*MockMetrics) AddCounter

func (m *MockMetrics) AddCounter(name string, value float64, labels map[string]string)

AddCounter mocks base method.

func (*MockMetrics) EXPECT

func (m *MockMetrics) EXPECT() *MockMetricsMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockMetrics) IncrementCounter

func (m *MockMetrics) IncrementCounter(name string, labels map[string]string)

IncrementCounter mocks base method.

func (*MockMetrics) RecordDuration

func (m *MockMetrics) RecordDuration(name string, d time.Duration, labels map[string]string)

RecordDuration mocks base method.

func (*MockMetrics) RecordHistogram

func (m *MockMetrics) RecordHistogram(name string, value float64, labels map[string]string)

RecordHistogram mocks base method.

func (*MockMetrics) SetGauge

func (m *MockMetrics) SetGauge(name string, value float64, labels map[string]string)

SetGauge mocks base method.

type MockMetricsMockRecorder

type MockMetricsMockRecorder struct {
	// contains filtered or unexported fields
}

MockMetricsMockRecorder is the mock recorder for MockMetrics.

func (*MockMetricsMockRecorder) AddCounter

func (mr *MockMetricsMockRecorder) AddCounter(name, value, labels any) *gomock.Call

AddCounter indicates an expected call of AddCounter.

func (*MockMetricsMockRecorder) IncrementCounter

func (mr *MockMetricsMockRecorder) IncrementCounter(name, labels any) *gomock.Call

IncrementCounter indicates an expected call of IncrementCounter.

func (*MockMetricsMockRecorder) RecordDuration

func (mr *MockMetricsMockRecorder) RecordDuration(name, d, labels any) *gomock.Call

RecordDuration indicates an expected call of RecordDuration.

func (*MockMetricsMockRecorder) RecordHistogram

func (mr *MockMetricsMockRecorder) RecordHistogram(name, value, labels any) *gomock.Call

RecordHistogram indicates an expected call of RecordHistogram.

func (*MockMetricsMockRecorder) SetGauge

func (mr *MockMetricsMockRecorder) SetGauge(name, value, labels any) *gomock.Call

SetGauge indicates an expected call of SetGauge.

type MockReconciler

type MockReconciler struct {
	// contains filtered or unexported fields
}

MockReconciler is a mock of Reconciler interface.

func NewMockReconciler

func NewMockReconciler(ctrl *gomock.Controller) *MockReconciler

NewMockReconciler creates a new mock instance.

func (*MockReconciler) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockReconciler) Run

func (m *MockReconciler) Run(ctx context.Context) error

Run mocks base method.

type MockReconcilerMockRecorder

type MockReconcilerMockRecorder struct {
	// contains filtered or unexported fields
}

MockReconcilerMockRecorder is the mock recorder for MockReconciler.

func (*MockReconcilerMockRecorder) Run

func (mr *MockReconcilerMockRecorder) Run(ctx any) *gomock.Call

Run indicates an expected call of Run.

type MockSpan

type MockSpan struct {
	// contains filtered or unexported fields
}

MockSpan is a mock of Span interface.

func NewMockSpan

func NewMockSpan(ctrl *gomock.Controller) *MockSpan

NewMockSpan creates a new mock instance.

func (*MockSpan) EXPECT

func (m *MockSpan) EXPECT() *MockSpanMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockSpan) End

func (m *MockSpan) End()

End mocks base method.

func (*MockSpan) RecordError

func (m *MockSpan) RecordError(err error)

RecordError mocks base method.

func (*MockSpan) SetAttributes

func (m *MockSpan) SetAttributes(attrs map[string]string)

SetAttributes mocks base method.

func (*MockSpan) SetStatus

func (m *MockSpan) SetStatus(code observability.StatusCode, description string)

SetStatus mocks base method.

type MockSpanMockRecorder

type MockSpanMockRecorder struct {
	// contains filtered or unexported fields
}

MockSpanMockRecorder is the mock recorder for MockSpan.

func (*MockSpanMockRecorder) End

func (mr *MockSpanMockRecorder) End() *gomock.Call

End indicates an expected call of End.

func (*MockSpanMockRecorder) RecordError

func (mr *MockSpanMockRecorder) RecordError(err any) *gomock.Call

RecordError indicates an expected call of RecordError.

func (*MockSpanMockRecorder) SetAttributes

func (mr *MockSpanMockRecorder) SetAttributes(attrs any) *gomock.Call

SetAttributes indicates an expected call of SetAttributes.

func (*MockSpanMockRecorder) SetStatus

func (mr *MockSpanMockRecorder) SetStatus(code, description any) *gomock.Call

SetStatus indicates an expected call of SetStatus.

type MockStore

type MockStore struct {
	// contains filtered or unexported fields
}

MockStore is a mock of Store interface.

func NewMockStore

func NewMockStore(ctrl *gomock.Controller) *MockStore

NewMockStore creates a new mock instance.

func (*MockStore) EXPECT

func (m *MockStore) EXPECT() *MockStoreMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockStore) Ping

func (m *MockStore) Ping(ctx context.Context) error

Ping mocks base method.

func (*MockStore) RecordRevocation

func (m *MockStore) RecordRevocation(ctx context.Context, event audit.RevocationEvent) error

RecordRevocation mocks base method.

type MockStoreMockRecorder

type MockStoreMockRecorder struct {
	// contains filtered or unexported fields
}

MockStoreMockRecorder is the mock recorder for MockStore.

func (*MockStoreMockRecorder) Ping

func (mr *MockStoreMockRecorder) Ping(ctx any) *gomock.Call

Ping indicates an expected call of Ping.

func (*MockStoreMockRecorder) RecordRevocation

func (mr *MockStoreMockRecorder) RecordRevocation(ctx, event any) *gomock.Call

RecordRevocation indicates an expected call of RecordRevocation.

type MockTenantRegistry

type MockTenantRegistry struct {
	// contains filtered or unexported fields
}

MockTenantRegistry is a mock of TenantRegistry interface.

func NewMockTenantRegistry

func NewMockTenantRegistry(ctrl *gomock.Controller) *MockTenantRegistry

NewMockTenantRegistry creates a new mock instance.

func (*MockTenantRegistry) Add added in v0.5.0

func (m *MockTenantRegistry) Add(ctx context.Context, tenantID string, cfg registry.TenantConfig) error

Add mocks base method.

func (*MockTenantRegistry) Drain added in v0.5.0

func (m *MockTenantRegistry) Drain(ctx context.Context, tenantID string) error

Drain mocks base method.

func (*MockTenantRegistry) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockTenantRegistry) Get

Get mocks base method.

func (*MockTenantRegistry) Remove added in v0.5.0

func (m *MockTenantRegistry) Remove(ctx context.Context, tenantID string) error

Remove mocks base method.

type MockTenantRegistryMockRecorder

type MockTenantRegistryMockRecorder struct {
	// contains filtered or unexported fields
}

MockTenantRegistryMockRecorder is the mock recorder for MockTenantRegistry.

func (*MockTenantRegistryMockRecorder) Add added in v0.5.0

func (mr *MockTenantRegistryMockRecorder) Add(ctx, tenantID, cfg any) *gomock.Call

Add indicates an expected call of Add.

func (*MockTenantRegistryMockRecorder) Drain added in v0.5.0

func (mr *MockTenantRegistryMockRecorder) Drain(ctx, tenantID any) *gomock.Call

Drain indicates an expected call of Drain.

func (*MockTenantRegistryMockRecorder) Get

func (mr *MockTenantRegistryMockRecorder) Get(ctx, tenantID any) *gomock.Call

Get indicates an expected call of Get.

func (*MockTenantRegistryMockRecorder) Remove added in v0.5.0

func (mr *MockTenantRegistryMockRecorder) Remove(ctx, tenantID any) *gomock.Call

Remove indicates an expected call of Remove.

type MockTokenManager added in v0.3.0

type MockTokenManager struct {
	// contains filtered or unexported fields
}

MockTokenManager is a mock of TokenManager interface.

func NewMockTokenManager added in v0.3.0

func NewMockTokenManager(ctrl *gomock.Controller) *MockTokenManager

NewMockTokenManager creates a new mock instance.

func (*MockTokenManager) CleanupExpiredTokens added in v0.6.0

func (m *MockTokenManager) CleanupExpiredTokens(ctx context.Context) (int, error)

CleanupExpiredTokens mocks base method.

func (*MockTokenManager) EXPECT added in v0.3.0

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockTokenManager) IntrospectToken added in v0.3.0

func (m *MockTokenManager) IntrospectToken(ctx context.Context, token string) (*tokens.TokenMetadata, error)

IntrospectToken mocks base method.

func (*MockTokenManager) IssueAccessToken added in v0.6.0

func (m *MockTokenManager) IssueAccessToken(ctx context.Context, userID string, opts ...tokens.IssueOption) (string, error)

IssueAccessToken mocks base method.

func (*MockTokenManager) IssueAccessTokenWithClaims added in v0.6.0

func (m *MockTokenManager) IssueAccessTokenWithClaims(ctx context.Context, userID string, claims tokens.CustomClaims, opts ...tokens.IssueOption) (string, error)

IssueAccessTokenWithClaims mocks base method.

func (*MockTokenManager) IssueRefreshToken added in v0.6.0

func (m *MockTokenManager) IssueRefreshToken(ctx context.Context, userID string, opts ...tokens.IssueOption) (string, error)

IssueRefreshToken mocks base method.

func (*MockTokenManager) IssueRefreshTokenWithClaims added in v0.6.0

func (m *MockTokenManager) IssueRefreshTokenWithClaims(ctx context.Context, userID string, claims tokens.CustomClaims, opts ...tokens.IssueOption) (string, error)

IssueRefreshTokenWithClaims mocks base method.

func (*MockTokenManager) IssueTokenPair added in v0.6.0

func (m *MockTokenManager) IssueTokenPair(ctx context.Context, userID string, opts ...tokens.IssueOption) (string, string, error)

IssueTokenPair mocks base method.

func (*MockTokenManager) IssueTokenPairWithClaims added in v0.3.0

func (m *MockTokenManager) IssueTokenPairWithClaims(ctx context.Context, userID string, accessClaims, refreshClaims tokens.CustomClaims, opts ...tokens.IssueOption) (string, string, error)

IssueTokenPairWithClaims mocks base method.

func (*MockTokenManager) ListTokens added in v0.6.0

func (m *MockTokenManager) ListTokens(ctx context.Context, cursor string, count int) ([]*storage.RefreshToken, string, error)

ListTokens mocks base method.

func (*MockTokenManager) ListTokensForAudience added in v0.6.0

func (m *MockTokenManager) ListTokensForAudience(ctx context.Context, audience, cursor string, count int) ([]*storage.RefreshToken, string, error)

ListTokensForAudience mocks base method.

func (*MockTokenManager) ListTokensForUser added in v0.6.0

func (m *MockTokenManager) ListTokensForUser(ctx context.Context, userID, cursor string, count int) ([]*storage.RefreshToken, string, error)

ListTokensForUser mocks base method.

func (*MockTokenManager) RefreshAccessToken added in v0.6.0

func (m *MockTokenManager) RefreshAccessToken(ctx context.Context, refreshToken string) (string, error)

RefreshAccessToken mocks base method.

func (*MockTokenManager) RefreshAccessTokenWithClaims added in v0.3.0

func (m *MockTokenManager) RefreshAccessTokenWithClaims(ctx context.Context, refreshToken string, claims tokens.CustomClaims) (string, error)

RefreshAccessTokenWithClaims mocks base method.

func (*MockTokenManager) RevokeAllForAudience added in v0.3.0

func (m *MockTokenManager) RevokeAllForAudience(ctx context.Context, audience string) error

RevokeAllForAudience mocks base method.

func (*MockTokenManager) RevokeAllForUserAndAudience added in v0.3.0

func (m *MockTokenManager) RevokeAllForUserAndAudience(ctx context.Context, userID, audience string) error

RevokeAllForUserAndAudience mocks base method.

func (*MockTokenManager) RevokeAllUserTokens added in v0.3.0

func (m *MockTokenManager) RevokeAllUserTokens(ctx context.Context, userID string) error

RevokeAllUserTokens mocks base method.

func (*MockTokenManager) RevokeRefreshToken added in v0.3.0

func (m *MockTokenManager) RevokeRefreshToken(ctx context.Context, tokenID string) error

RevokeRefreshToken mocks base method.

func (*MockTokenManager) ValidateAccessToken added in v0.3.0

func (m *MockTokenManager) ValidateAccessToken(ctx context.Context, tokenString string) (*jwt.RegisteredClaims, error)

ValidateAccessToken mocks base method.

func (*MockTokenManager) ValidateAccessTokenWithClaims added in v0.3.0

func (m *MockTokenManager) ValidateAccessTokenWithClaims(ctx context.Context, tokenString string) (*jwt.RegisteredClaims, map[string]any, error)

ValidateAccessTokenWithClaims mocks base method.

type MockTokenManagerMockRecorder added in v0.3.0

type MockTokenManagerMockRecorder struct {
	// contains filtered or unexported fields
}

MockTokenManagerMockRecorder is the mock recorder for MockTokenManager.

func (*MockTokenManagerMockRecorder) CleanupExpiredTokens added in v0.6.0

func (mr *MockTokenManagerMockRecorder) CleanupExpiredTokens(ctx any) *gomock.Call

CleanupExpiredTokens indicates an expected call of CleanupExpiredTokens.

func (*MockTokenManagerMockRecorder) IntrospectToken added in v0.3.0

func (mr *MockTokenManagerMockRecorder) IntrospectToken(ctx, token any) *gomock.Call

IntrospectToken indicates an expected call of IntrospectToken.

func (*MockTokenManagerMockRecorder) IssueAccessToken added in v0.6.0

func (mr *MockTokenManagerMockRecorder) IssueAccessToken(ctx, userID any, opts ...any) *gomock.Call

IssueAccessToken indicates an expected call of IssueAccessToken.

func (*MockTokenManagerMockRecorder) IssueAccessTokenWithClaims added in v0.6.0

func (mr *MockTokenManagerMockRecorder) IssueAccessTokenWithClaims(ctx, userID, claims any, opts ...any) *gomock.Call

IssueAccessTokenWithClaims indicates an expected call of IssueAccessTokenWithClaims.

func (*MockTokenManagerMockRecorder) IssueRefreshToken added in v0.6.0

func (mr *MockTokenManagerMockRecorder) IssueRefreshToken(ctx, userID any, opts ...any) *gomock.Call

IssueRefreshToken indicates an expected call of IssueRefreshToken.

func (*MockTokenManagerMockRecorder) IssueRefreshTokenWithClaims added in v0.6.0

func (mr *MockTokenManagerMockRecorder) IssueRefreshTokenWithClaims(ctx, userID, claims any, opts ...any) *gomock.Call

IssueRefreshTokenWithClaims indicates an expected call of IssueRefreshTokenWithClaims.

func (*MockTokenManagerMockRecorder) IssueTokenPair added in v0.6.0

func (mr *MockTokenManagerMockRecorder) IssueTokenPair(ctx, userID any, opts ...any) *gomock.Call

IssueTokenPair indicates an expected call of IssueTokenPair.

func (*MockTokenManagerMockRecorder) IssueTokenPairWithClaims added in v0.3.0

func (mr *MockTokenManagerMockRecorder) IssueTokenPairWithClaims(ctx, userID, accessClaims, refreshClaims any, opts ...any) *gomock.Call

IssueTokenPairWithClaims indicates an expected call of IssueTokenPairWithClaims.

func (*MockTokenManagerMockRecorder) ListTokens added in v0.6.0

func (mr *MockTokenManagerMockRecorder) ListTokens(ctx, cursor, count any) *gomock.Call

ListTokens indicates an expected call of ListTokens.

func (*MockTokenManagerMockRecorder) ListTokensForAudience added in v0.6.0

func (mr *MockTokenManagerMockRecorder) ListTokensForAudience(ctx, audience, cursor, count any) *gomock.Call

ListTokensForAudience indicates an expected call of ListTokensForAudience.

func (*MockTokenManagerMockRecorder) ListTokensForUser added in v0.6.0

func (mr *MockTokenManagerMockRecorder) ListTokensForUser(ctx, userID, cursor, count any) *gomock.Call

ListTokensForUser indicates an expected call of ListTokensForUser.

func (*MockTokenManagerMockRecorder) RefreshAccessToken added in v0.6.0

func (mr *MockTokenManagerMockRecorder) RefreshAccessToken(ctx, refreshToken any) *gomock.Call

RefreshAccessToken indicates an expected call of RefreshAccessToken.

func (*MockTokenManagerMockRecorder) RefreshAccessTokenWithClaims added in v0.3.0

func (mr *MockTokenManagerMockRecorder) RefreshAccessTokenWithClaims(ctx, refreshToken, claims any) *gomock.Call

RefreshAccessTokenWithClaims indicates an expected call of RefreshAccessTokenWithClaims.

func (*MockTokenManagerMockRecorder) RevokeAllForAudience added in v0.3.0

func (mr *MockTokenManagerMockRecorder) RevokeAllForAudience(ctx, audience any) *gomock.Call

RevokeAllForAudience indicates an expected call of RevokeAllForAudience.

func (*MockTokenManagerMockRecorder) RevokeAllForUserAndAudience added in v0.3.0

func (mr *MockTokenManagerMockRecorder) RevokeAllForUserAndAudience(ctx, userID, audience any) *gomock.Call

RevokeAllForUserAndAudience indicates an expected call of RevokeAllForUserAndAudience.

func (*MockTokenManagerMockRecorder) RevokeAllUserTokens added in v0.3.0

func (mr *MockTokenManagerMockRecorder) RevokeAllUserTokens(ctx, userID any) *gomock.Call

RevokeAllUserTokens indicates an expected call of RevokeAllUserTokens.

func (*MockTokenManagerMockRecorder) RevokeRefreshToken added in v0.3.0

func (mr *MockTokenManagerMockRecorder) RevokeRefreshToken(ctx, tokenID any) *gomock.Call

RevokeRefreshToken indicates an expected call of RevokeRefreshToken.

func (*MockTokenManagerMockRecorder) ValidateAccessToken added in v0.3.0

func (mr *MockTokenManagerMockRecorder) ValidateAccessToken(ctx, tokenString any) *gomock.Call

ValidateAccessToken indicates an expected call of ValidateAccessToken.

func (*MockTokenManagerMockRecorder) ValidateAccessTokenWithClaims added in v0.3.0

func (mr *MockTokenManagerMockRecorder) ValidateAccessTokenWithClaims(ctx, tokenString any) *gomock.Call

ValidateAccessTokenWithClaims indicates an expected call of ValidateAccessTokenWithClaims.

type MockTracer

type MockTracer struct {
	// contains filtered or unexported fields
}

MockTracer is a mock of Tracer interface.

func NewMockTracer

func NewMockTracer(ctrl *gomock.Controller) *MockTracer

NewMockTracer creates a new mock instance.

func (*MockTracer) EXPECT

func (m *MockTracer) EXPECT() *MockTracerMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockTracer) Start

Start mocks base method.

type MockTracerMockRecorder

type MockTracerMockRecorder struct {
	// contains filtered or unexported fields
}

MockTracerMockRecorder is the mock recorder for MockTracer.

func (*MockTracerMockRecorder) Start

func (mr *MockTracerMockRecorder) Start(ctx, name any) *gomock.Call

Start indicates an expected call of Start.

Jump to